from datetime import datetime

import pymysql


class MySQLClient:
    def __init__(self, host, user, password, db, port=3306):
        self.conn = pymysql.connect(
            host=host,
            user=user,
            password=password,
            db=db,
            port=port,
            charset='utf8mb4',
            cursorclass=pymysql.cursors.DictCursor,
            autocommit=True
        )
        self.cursor = self.conn.cursor()

    def execute(self, sql, values=None):
        try:
            self.cursor.execute(sql, values or [])

        except Exception as e:
            print(f"[MySQL] 执行失败: {e}")
            self.conn.rollback()

    def __del__(self):
        try:
            self.cursor.close()
            self.conn.close()
        except Exception:
            pass


class DB:
    _client: MySQLClient = None  # 类属性持有连接

    @classmethod
    def init(cls):
        if cls._client is None:
            cls._client = MySQLClient(
                host='39.101.135.56',
                user='tsreshub_prod',
                password='Tr5h$Prod!92@TsRH',
                db='tsreshub_db',
                port=3306
            )

    @classmethod
    def insert_resume(cls, data: dict):
        cls.init()  # 保证连接已初始化

        # 只保留基本数据类型
        safe_data = {k: v for k, v in data.items() if isinstance(v, (str, int, float, type(None), datetime))}

        if 'resume_id' not in safe_data or 'source_id' not in safe_data:
            # 必须有 source_id + resume_id
            return

        table = 'resumes_resumebasic'
        keys = ', '.join(safe_data.keys())
        placeholders = ', '.join(['%s'] * len(safe_data))

        # 注意：update时排除 source_id 和 resume_id
        update_clause = ', '.join([f"{k} = VALUES({k})" for k in safe_data if k not in ('source_id', 'resume_id')])

        sql = f"""
            INSERT INTO {table} ({keys}) VALUES ({placeholders})
            ON DUPLICATE KEY UPDATE {update_clause}
        """

        cls._client.execute(sql, list(safe_data.values()))

    @classmethod
    def insert_company(cls, data: dict):
        if cls._client is None:
            raise RuntimeError("数据库未初始化。首先调用DB.init()。")

        safe_data = {k: v for k, v in data.items() if isinstance(v, (str, int, float, type(None), datetime))}
        if 'name' not in safe_data or 'website' not in safe_data:
            return

        table = 'companies_company'
        keys = ', '.join(safe_data.keys())
        holders = ', '.join(['%s'] * len(safe_data))
        updates = ', '.join([f"{k}=VALUES({k})" for k in safe_data if k not in ('name','website')])
        sql = (
            f"INSERT INTO {table} ({keys}) VALUES ({holders}) "
            f"ON DUPLICATE KEY UPDATE {updates}"
        )
        cls._client.execute(sql, list(safe_data.values()))